@@ -14,14 +14,15 @@ use Interchange6::Schema::Populate::Zone;
 use Sub::Quote qw/quote_sub/;
 use DateTime;
 
-use Test::Roo::Role;
+use Moo::Role;
 
 # accessors are ordered in this array based on the order in which
 # clear_all_fixtures needs to receive them so that there are no FK issues in
 # the database during row deletion
 
-my @accessors =
-  qw(orders addresses taxes zones states countries navigation roles price_modifiers inventory media products attributes users message_types);
+my @accessors = qw(orders addresses shipment_rates taxes zones states
+  countries navigation price_modifiers roles inventory media products
+  attributes users message_types shipment_carriers);
 
 # Create all of the accessors and clearers. Builders should be defined later.
 
@@ -33,6 +34,7 @@ foreach my $accessor (@accessors) {
     );
 
     next if $accessor eq 'media';       # see below
+    next if $accessor eq 'orders';      # see below
     next if $accessor eq 'products';    # see below
 
     my $cref = q{
@@ -57,6 +59,16 @@ sub clear_media {
     $self->_clear_media;
 }
 
+sub clear_orders {
+    my $self = shift;
+    my $schema = $self->ic6s_schema;
+    $schema->resultset('OrderlinesShipping')->delete;
+    $schema->resultset('Shipment')->delete;
+    $schema->resultset('Orderline')->delete;
+    $schema->resultset('Order')->delete;
+    $self->_clear_orders;
+}
+
 sub clear_products {
     my $self = shift;
 
@@ -190,7 +202,6 @@ sub _build_roles {
     # Add a few additional roles
     scalar $rset->populate(
         [
-            { name => 'user', label => 'User', description => 'Basic User' },
             { name => 'editor', label => 'Editor', description => 'Editor' },
             { name => 'wholesale', label => 'Wholesale customer', description => 'Wholesale Customer.' },
             { name => 'trade', label => 'Trade customer', description => 'Trade Customer.' },
@@ -207,11 +218,13 @@ sub _build_orders {
     my $self = shift;
     my $schema = $self->ic6s_schema;
 
+    # prereqs
+    $self->products unless $self->has_products;
+    $self->addresses unless $self->has_addresses;
+
     my $rset =  $schema->resultset('Order');
 
-    my $customer1 =
-      $self->users->search( { username => 'customer1' }, { rows => 1 } )
-      ->single;
+    my $customer1 = $self->users->find( { username => 'customer1' } );
 
     my $billing_address =
       $customer1->addresses->search( { type => 'billing' }, { rows => 1 } )
@@ -261,6 +274,116 @@ sub _build_orders {
         }
     );
 
+    my $customer2 = $self->users->find( { username => 'customer2' });
+
+    $billing_address =
+      $customer2->addresses->search( { type => 'billing' }, { rows => 1 } )
+      ->single;
+
+    $shipping_address =
+      $customer2->addresses->search( { type => 'shipping' }, { rows => 1 } )
+      ->single;
+
+    $payment_order = {
+        users_id => $customer2->id,
+        amount   => 56.47,
+    };
+
+    $rset->create(
+        {
+            order_number          => '122339',
+            order_date            => DateTime->now,
+            users_id              => $customer2->id,
+            email                 => $customer2->email,
+            shipping_addresses_id => $shipping_address->id,
+            billing_addresses_id  => $billing_address->id,
+            orderlines            => \@orderlines,
+            subtotal              => 43.97,
+            shipping              => 12.50,
+            total_cost            => 56.47,
+            payment_orders        => [$payment_order],
+        }
+    );
+
+    return $rset;
+}
+
+=head2 shipment_carriers
+
+=cut
+
+sub _build_shipment_carriers {
+    my $self = shift;
+    my $rset = $self->ic6s_schema->resultset('ShipmentCarrier');
+
+    $rset->create(
+        {
+            name             => 'UPS',
+            account_number   => '1U99999',
+            shipment_methods => [
+                {
+                    name       => '1DM',
+                    title      => 'Next Day Air Early AM',
+                    max_weight => '150',
+
+                },
+                {
+                    name       => 'GNDRES',
+                    title      => 'Ground Residential',
+                    max_weight => '150',
+                }
+            ]
+        }
+    );
+    $rset->create(
+        {
+            name             => 'KISS',
+            account_number   => '1K99999',
+            shipment_methods => [
+                {
+                    name       => 'KISSFAST',
+                    title      => 'Keep it Simple and Stupid',
+                    max_weight => '60',
+                },
+            ]
+        }
+    );
+    return $rset;
+}
+
+=head2 shipment_rates
+
+=cut
+
+sub _build_shipment_rates {
+    my $self   = shift;
+    my $schema = $self->ic6s_schema;
+    my $rset   = $schema->resultset('ShipmentRate');
+
+    # prereqs
+    $self->shipment_carriers unless $self->has_shipment_carriers;
+    $self->zones unless $self->has_zones;
+
+    $rset->create(
+        {
+            zones_id => $self->zones->find( { zone => 'US lower 48' } )->id,
+            shipment_methods_id => $schema->resultset('ShipmentMethod')
+              ->search( { name => 'GNDRES' }, { rows => 1 } )->single->id,
+            min_weight => 0,
+            max_weight => 0,
+            price      => 9.95,
+        },
+    );
+    $rset->create(
+        {
+            zones_id => $self->zones->find( { zone => 'US lower 48' } )->id,
+            shipment_methods_id => $schema->resultset('ShipmentMethod')
+              ->search( { name => '1DM' }, { rows => 1 } )->single->id,
+            min_weight => 0,
+            max_weight => 0,
+            price      => 29.95,
+        },
+    );
     return $rset;
 }
 
@@ -281,10 +404,8 @@ sub _build_price_modifiers {
 
     my $product = $self->products->find(
         { sku => 'G0001' });
-    my $role_anonymous = $self->roles->find(
-        { name => 'anonymous' });
-    my $role_authenticated = $self->roles->find(
-        { name => 'authenticated' });
+    my $role_user = $self->roles->find(
+        { name => 'user' });
     my $role_trade = $self->roles->find(
         { name => 'trade' });
     my $role_wholesale = $self->roles->find(
@@ -293,21 +414,22 @@ sub _build_price_modifiers {
     scalar $rset->populate(
         [
             [qw/sku quantity roles_id price start_date end_date/],
-            [ 'os28004', 10,  $role_anonymous->id,     19, undef, undef ],
-            [ 'os28004', 10,  $role_authenticated->id, 19, undef, undef ],
-            [ 'os28004', 20,  $role_authenticated->id, 18, undef, undef ],
-            [ 'os28004', 30,  $role_authenticated->id, 17, undef, undef ],
-            [ 'os28004', 1,   $role_trade->id,         18, undef, undef ],
-            [ 'os28004', 10,  $role_trade->id,         17, undef, undef ],
-            [ 'os28004', 20,  $role_trade->id,         16, undef, undef ],
-            [ 'os28004', 50,  $role_trade->id,         15, undef, undef ],
-            [ 'os28004', 1,   $role_wholesale->id,     12, undef, undef ],
-            [ 'os28004', 10,  $role_wholesale->id,     11, undef, undef ],
-            [ 'os28004', 20,  $role_wholesale->id,     10, undef, undef ],
-            [ 'os28004', 50,  $role_wholesale->id,     9,  undef, undef ],
-            [ 'os28004', 200, $role_wholesale->id,     8,  undef, undef ],
-            [ 'os28004', 1, $role_anonymous->id, 19.20, $start, $end ],
-            [ 'os28004', 1, $role_trade->id,     17,    $start, $end ],
+            [ 'os28005', 10,  undef,               8.49,  undef,  undef ],
+            [ 'os28005', 10,  $role_user->id,      8.20,  undef,  undef ],
+            [ 'os28005', 20,  $role_user->id,      8.00,  undef,  undef ],
+            [ 'os28005', 30,  $role_user->id,      7.80,  undef,  undef ],
+            [ 'os28005', 1,   $role_trade->id,     8,     undef,  undef ],
+            [ 'os28005', 10,  $role_trade->id,     7.80,  undef,  undef ],
+            [ 'os28005', 20,  $role_trade->id,     7.50,  undef,  undef ],
+            [ 'os28005', 50,  $role_trade->id,     7,     undef,  undef ],
+            [ 'os28005', 1,   $role_wholesale->id, 7,     undef,  undef ],
+            [ 'os28005', 10,  $role_wholesale->id, 6.80,  undef,  undef ],
+            [ 'os28005', 20,  $role_wholesale->id, 6.70,  undef,  undef ],
+            [ 'os28005', 50,  $role_wholesale->id, 6.50,  undef,  undef ],
+            [ 'os28005', 200, $role_wholesale->id, 6.10,  undef,  undef ],
+            [ 'os28005', 1,   undef,               7.50,  $start, $end ],
+            [ 'os28005', 1,   $role_trade->id,     6.90,  $start, $end ],
+            [ 'os28006', 1,   undef,               24.99, undef,  undef ],
         ]
     );
     return $rset;
@@ -675,10 +797,147 @@ qq(Extend the reach of your potting with "The Claw".  Perfect for agitating soil
             44.99,              "3-foot-step-ladder",
             0
         ],
+        [
+            "sv13213",
+            "Painting Service",
+            "Let our professional painters do the work for you",
+"If you don't have time for DIY then why not take advantage of our professional painting service. Fixed hourly rates for any job",
+            75,
+            "professional-painting-service",
+            0
+        ]
     );
 
     scalar $rset->populate( [@products] );
 
+    # sv13213 is inventory_exempt
+    $rset->find( { sku => "sv13213" } )->update( { inventory_exempt => 1 } );
+
+    $rset->find( { sku => "os28057a" } )
+      ->add_attribute( { type => 'simple', name => 'length' }, '3.5 inches' );
+
+    $rset->find( { sku => "os28057b" } )
+    ->add_attribute( { type => 'simple', name => 'length' }, '2.5 inches' );
+
+    $rset->find( { sku => "os28057c" } )
+      ->add_attribute( { type => 'simple', name => 'length' }, '3.0 inches' );
+
+    $rset->find( { sku => "os28057a" } )
+      ->add_attribute( { type => 'simple', name => 'box_quantity' }, '100' );
+
+    $rset->find( { sku => "os28057b" } )
+      ->add_attribute( { type => 'simple', name => 'box_quantity' }, '200' );
+
+    $rset->find( { sku => "os28057c" } )
+      ->add_attribute( { type => 'simple', name => 'box_quantity' }, '100' );
+
+    $rset->find( { sku => "os28085" } )->add_variants(
+        {
+            sku   => 'os28085-6',
+            price => 36.99,
+            uri   => 'big-a-a-frame-ladder-6-foot-high',
+            height => '6 foot',
+        },
+        {
+            sku   => 'os28085-12',
+            price => 54.99,
+            uri   => 'big-a-a-frame-ladder-12-foot-high',
+            height => '12 foot',
+        },
+    );
+    $rset->find( { sku => "os28080" } )->add_variants(
+        {
+            sku   => 'os28080-1',
+            price => 19.99,
+            uri   => 'the-blade-hand-planer-one-inch-wide',
+            width => '1.0 inch',
+        },
+        {
+            sku   => 'os28080-1HLF',
+            price => 20.99,
+            uri   => 'the-blade-hand-planer-one-and-a-half-inches-wide',
+            width => '1.5 inch',
+        },
+        {
+            sku   => 'os28080-2',
+            price => 21.99,
+            uri   => 'the-blade-hand-planer-two-inches-wide',
+            width => '2.0 inch',
+        },
+    );
+    $rset->find( { sku => "os28072" } )->add_variants(
+        {
+            sku    => 'os28072-2',
+            price  => 16.99,
+            uri    => 'deluxe-hand-saw-two-foot',
+            length => '2 foot',
+        },
+        {
+            sku    => 'os28072-2HLF',
+            price  => 17.99,
+            uri    => 'deluxe-hand-saw-two-and-a-half-foot',
+            length => '2.5 foot',
+        },
+        {
+            sku    => 'os28072-3',
+            price  => 18.99,
+            uri    => 'deluxe-hand-saw-three-foot',
+            length => '3 foot',
+        },
+    );
+    $rset->find( { sku => "os28065" } )->add_variants(
+        {
+            diameter => '1/4 inch',
+            sku      => 'os28065-QTR',
+            uri      => 'mechanics-pliers-quarter-inch-diameter',
+        },
+        {
+            diameter => '1/2 inch',
+            sku      => 'os28065-HLF',
+            uri      => 'mechanics-pliers-half-inch-diameter',
+        },
+        {
+            diameter => '1 inch',
+            sku      => 'os28065-1',
+            uri      => 'mechanics-pliers-1-inch-diameter',
+        },
+        {
+            diameter => '2 inches',
+            sku      => 'os28065-2',
+            uri      => 'mechanics-pliers-2-inch-diameter',
+        },
+        {
+            diameter => '3 inches',
+            sku      => 'os28065-3',
+            uri      => 'mechanics-pliers-3-inch-diameter',
+        },
+    );
+    $rset->find( { sku => "os28084" } )->add_variants(
+        {
+            length => '10 foot',
+            sku    => 'os28084-10',
+            uri    => 'tape-measure-10-foot-long',
+            price  => 10.99,
+        },
+        {
+            length => '16 foot',
+            sku    => 'os28084-16',
+            uri    => 'tape-measure-16-foot-long',
+            price  => 12.99,
+        },
+        {
+            length => '24 foot',
+            sku    => 'os28084-24',
+            uri    => 'tape-measure-24-foot-long',
+            price  => 15.99,
+        },
+        {
+            length => '36 foot',
+            sku    => 'os28084-36',
+            uri    => 'tape-measure-36-foot-long',
+            price  => 19.99,
+        },
+    );
     $rset->find( { sku => "os28004" } )->add_variants(
         {
             roller => 'camel',
@@ -781,7 +1040,7 @@ qq(Extend the reach of your potting with "The Claw".  Perfect for agitating soil
             title   => "fantastic",
             content => "really amazing",
             rating  => 5,
-            author  => $customer1->id,
+            author_users_id => $customer1->id,
             public  => 1,
             approved => 1,
         },
@@ -789,7 +1048,7 @@ qq(Extend the reach of your potting with "The Claw".  Perfect for agitating soil
             title   => "great",
             content => "there is so much I wan to say",
             rating  => 4.8,
-            author  => $customer1->id,
+            author_users_id => $customer1->id,
             public  => 1,
             approved => 1,
         },
@@ -797,7 +1056,7 @@ qq(Extend the reach of your potting with "The Claw".  Perfect for agitating soil
             title   => "brilliant",
             content => "let me carp on about this great product",
             rating  => 4.7,
-            author  => $customer1->id,
+            author_users_id => $customer1->id,
             public  => 1,
             approved => 1,
         },
@@ -805,7 +1064,7 @@ qq(Extend the reach of your potting with "The Claw".  Perfect for agitating soil
             title   => "fantastic",
             content => "public but not approved",
             rating  => 4,
-            author  => $customer1->id,
+            author_users_id => $customer1->id,
             public  => 1,
             approved => 0,
         },
@@ -813,7 +1072,7 @@ qq(Extend the reach of your potting with "The Claw".  Perfect for agitating soil
             title   => "fantastic",
             content => "approved but not public",
             rating  => 4,
-            author  => $customer1->id,
+            author_users_id => $customer1->id,
             public  => 0,
             approved => 1,
         },
@@ -821,7 +1080,7 @@ qq(Extend the reach of your potting with "The Claw".  Perfect for agitating soil
             title   => "really good",
             content => "does what it says on the tin",
             rating  => 4.3,
-            author  => $customer1->id,
+            author_users_id => $customer1->id,
             public  => 1,
             approved => 1,
         },
@@ -829,7 +1088,7 @@ qq(Extend the reach of your potting with "The Claw".  Perfect for agitating soil
             title   => "amazing",
             content => "so good I bought one for my dad",
             rating  => 3.8,
-            author  => $customer1->id,
+            author_users_id => $customer1->id,
             public  => 1,
             approved => 1,
         },
@@ -837,7 +1096,7 @@ qq(Extend the reach of your potting with "The Claw".  Perfect for agitating soil
             title   => "not bad",
             content => "better available on the market but not at this price",
             rating  => 3,
-            author  => $customer1->id,
+            author_users_id => $customer1->id,
             public  => 1,
             approved => 1,
         },
@@ -845,7 +1104,7 @@ qq(Extend the reach of your potting with "The Claw".  Perfect for agitating soil
             title   => "total junk",
             content => "product is completely worthless",
             rating  => 0,
-            author  => $customer1->id,
+            author_users_id => $customer1->id,
             public  => 0,
             approved => 0,
         },
@@ -866,6 +1125,96 @@ sub _build_attributes {
     my $self = shift;
     my $rset = $self->ic6s_schema->resultset('Attribute');
 
+    # generic product attributes
+    $rset->create(
+        {
+            name  => 'box_quantity',
+            title => 'Qty in box',
+            type  => 'simple',
+            attribute_values => [
+                { value => '100', title => '100' },
+                { value => '200', title => '200' },
+            ]
+        }
+    );
+    $rset->create(
+        {
+            name             => 'length',
+            title            => 'Length',
+            type             => 'simple',
+            attribute_values => [
+                { value => '2.5 inches', title => q(2½") },
+                { value => '3.0 inches', title => q(3") },
+                { value => '3.5 inches', title => q(3½") },
+            ]
+        }
+    );
+
+    # variants
+    $rset->create(
+        {
+            name             => 'width',
+            title            => 'Width',
+            type             => 'variant',
+            priority         => 1,
+            attribute_values => [
+                { priority => 40, value => '1.0 inch',   title => q(1") },
+                { priority => 30, value => '1.5 inch', title => q(1.5") },
+                { priority => 20, value => '2.0 inch', title => q(2") },
+            ]
+        }
+    );
+    $rset->create(
+        {
+            name             => 'diameter',
+            title            => 'Diameter',
+            type             => 'variant',
+            priority         => 1,
+            attribute_values => [
+                { priority => 80, value => '1/4 inch', title => q(1/4") },
+                { priority => 70, value => '1/2 inch', title => q(1/2") },
+                { priority => 60, value => '1 inch',   title => q(1") },
+                { priority => 50, value => '2 inches', title => q(2") },
+                { priority => 40, value => '3 inches', title => q(3") },
+            ]
+        }
+    );
+    $rset->create(
+        {
+            name             => 'height',
+            title            => 'Height',
+            type             => 'variant',
+            priority         => 2,
+            attribute_values => [
+                { priority => 800,  value => '2 foot',   title => "2'" },
+                { priority => 750,  value => '2.5 foot', title => "2.5'" },
+                { priority => 700,  value => '3 foot',   title => "3'" },
+                { priority => 650,  value => '6 foot',   title => "6'" },
+                { priority => 600, value => '10 foot',  title => "10'" },
+                { priority => 550, value => '12 foot',  title => "12'" },
+                { priority => 500, value => '16 foot',  title => "16'" },
+                { priority => 450, value => '24 foot',  title => "24'" },
+                { priority => 400, value => '36 foot',  title => "36'" },
+            ]
+        }
+    );
+    $rset->create(
+        {
+            name             => 'length',
+            title            => 'Length',
+            type             => 'variant',
+            priority         => 1,
+            attribute_values => [
+                { priority => 80,  value => '2 foot',   title => "2'" },
+                { priority => 85,  value => '2.5 foot', title => "2.5'" },
+                { priority => 80,  value => '3 foot',   title => "3'" },
+                { priority => 75, value => '10 foot',  title => "10'" },
+                { priority => 70, value => '16 foot',  title => "16'" },
+                { priority => 65, value => '24 foot',  title => "24'" },
+                { priority => 60, value => '36 foot',  title => "36'" },
+            ]
+        }
+    );
     $rset->create(
         {
             name             => 'color',
@@ -910,7 +1259,7 @@ sub _build_attributes {
             type             => 'variant',
             priority         => 1,
             attribute_values => [
-                { value => 'plastic',  title => 'Ebony' },
+                { value => 'plastic',  title => 'Plastic' },
                 { value => 'steel',    title => 'Steel' },
                 { value => 'titanium', title => 'Titanium' },
             ]
@@ -932,46 +1281,68 @@ sub _build_inventory {
     $self->products unless $self->has_products;
 
     my @inventory = (
-        [qw(sku quantity)],
-        [ "os28004",  92 ],
-        [ "os28005",  100 ],
-        [ "os28006",  90 ],
-        [ "os28007",  85 ],
-        [ "os28008",  100 ],
-        [ "os28009",  95 ],
-        [ "os28011",  40 ],
-        [ "os28044",  100 ],
-        [ "os28057a", 100 ],
-        [ "os28057b", 29 ],
-        [ "os28057c", 50 ],
-        [ "os28062",  88 ],
-        [ "os28064",  94 ],
-        [ "os28065",  100 ],
-        [ "os28066",  100 ],
-        [ "os28068a", 100 ],
-        [ "os28068b", 99 ],
-        [ "os28069",  100 ],
-        [ "os28070",  0 ],
-        [ "os28072",  100 ],
-        [ "os28073",  0 ],
-        [ "os28074",  95 ],
-        [ "os28075",  100 ],
-        [ "os28076",  100 ],
-        [ "os28077",  97 ],
-        [ "os28080",  84 ],
-        [ "os28081",  100 ],
-        [ "os28082",  99 ],
-        [ "os28084",  95 ],
-        [ "os28085",  1 ],
-        [ "os28086",  100 ],
-        [ "os28087",  30 ],
-        [ "os28108",  90 ],
-        [ "os28109",  100 ],
-        [ "os28110",  99 ],
-        [ "os28111",  99 ],
-        [ "os28112",  100 ],
-        [ "os28113",  100 ],
-        [ "os29000",  97 ],
+        [qw(sku quantity )],
+        [ "os28004-CAM-BLK", 34, ],
+        [ "os28004-CAM-WHT", 27, ],
+        [ "os28004-HUM-BLK", 19, ],
+        [ "os28004-HUM-WHT", 131, ],
+        [ "os28004-SYN-BLK", 0, ],
+        [ "os28004-SYN-WHT", 42, ],
+        [ "os28005",         100, ],
+        [ "os28006",         90, ],
+        [ "os28007",         85, ],
+        [ "os28008",         100, ],
+        [ "os28009",         0, ],
+        [ "os28011",         40, ],
+        [ "os28044",         3, ],
+        [ "os28057a",        100, ],
+        [ "os28057b",        29, ],
+        [ "os28057c",        50, ],
+        [ "os28062",         88, ],
+        [ "os28064",         94, ],
+        [ 'os28065-QTR',     103, ],
+        [ 'os28065-HLF',     87, ],
+        [ 'os28065-1',       3, ],
+        [ 'os28065-2',       0, ],
+        [ 'os28065-3',       49, ],
+        [ "os28066-E-P",     98, ],
+        [ "os28066-E-S",     67, ],
+        [ "os28066-E-T",     42, ],
+        [ "os28066-W-P",     103, ],
+        [ "os28066-W-S",     7, ],
+        # os28066-W-T intentionally not added to inventory
+        [ "os28068a",     100, ],
+        [ "os28068b",     99, ],
+        [ "os28069",      100, ],
+        [ "os28070",      0, ],
+        [ 'os28072-2',    19, ],
+        [ 'os28072-2HLF', 47, ],
+        [ 'os28072-3',    23, ],
+        [ "os28073",      0, ],
+        [ "os28074",      95, ],
+        [ "os28075",      100, ],
+        [ "os28076",      100, ],
+        [ "os28077",      97, ],
+        [ 'os28080-1',    67, ],
+        [ 'os28080-1HLF', 32, ],
+        [ 'os28080-2',    145, ],
+        [ "os28081",      100, ],
+        [ "os28082",      99, ],
+        [ "os28084-10",   56, ],
+        [ "os28084-16",   9, ],
+        [ "os28084-24",   0, ],
+        [ "os28084-36",   45, ],
+        [ 'os28085-6',    3, ],
+        [ 'os28085-12',   0, ],
+        [ "os28086",      100, ],
+        [ "os28087",      30, ],
+        [ "os28108",      90, ],
+        [ "os28109",      100, ],
+        [ "os28110",      99, ],
+        [ "os28111",      99, ],
+        [ "os28112",      100, ],
+        [ "os28113",      100, ],
+        # os29000 intentionally not added to inventory
     );
 
     scalar $rset->populate( [@inventory] );
@@ -1041,16 +1412,22 @@ sub _build_navigation {
     my $self = shift;
     my $rset = $self->ic6s_schema->resultset('Navigation');
 
+    # we must have products before we can proceed
+    $self->products unless $self->has_products;
+
     scalar $rset->populate(
         [
             [ 'uri',        'type', 'scope',     'name',       'priority' ],
-            [ 'hand-tools', 'nav',  'menu-main', 'Hand Tools', 1 ],
-            [ 'hardware',   'nav',  'menu-main', 'Hardware',   2 ],
-            [ 'ladders',    'nav',  'menu-main', 'Ladders',    3 ],
-            [ 'measuring-tools',   'nav', 'menu-main', 'Measuring Tools',   4 ],
-            [ 'painting-supplies', 'nav', 'menu-main', 'Painting Supplies', 5 ],
-            [ 'safety-equipment',  'nav', 'menu-main', 'Safety Equipment',  6 ],
-            [ 'tool-storage',      'nav', 'menu-main', 'Tool Storage',      7 ],
+            [ 'hand-tools', 'nav',  'menu-main', 'Hand Tools', 90 ],
+            [ 'hardware',   'nav',  'menu-main', 'Hardware',   80 ],
+            [ 'ladders',    'nav',  'menu-main', 'Ladders',    70 ],
+            [ 'measuring-tools', 'nav', 'menu-main', 'Measuring Tools', 60 ],
+            [
+                'painting-supplies', 'nav', 'menu-main', 'Painting Supplies',
+                50
+            ],
+            [ 'safety-equipment', 'nav', 'menu-main', 'Safety Equipment', 40 ],
+            [ 'tool-storage',     'nav', 'menu-main', 'Tool Storage',     30 ],
         ]
     );
 
@@ -1192,7 +1569,7 @@ sub _build_navigation {
                 name      => $nav->[3],
                 parent_id => $nav->[4],
                 navigation_products =>
-                  [ map { { "sku" => $_ } } @{ $nav->[5] } ],
+                  [ map { { "sku" => $_, priority => 100 } } @{ $nav->[5] } ],
             }
         );
 
@@ -1334,14 +1711,30 @@ sub _build_taxes {
 sub _build_users {
     my $self    = shift;
     my $rset    = $self->ic6s_schema->resultset('User');
+
+    # we must have roles before we can proceed
+    $self->roles unless $self->has_roles;
+
     scalar $rset->populate(
         [
-            [qw( username email password )],
-            [ 'customer1', 'customer1@example.com', 'c1passwd' ],
-            [ 'customer2', 'customer2@example.com', 'c1passwd' ],
-            [ 'customer3', 'customer3@example.com', 'c1passwd' ],
-            [ 'admin1',    'admin1@example.com',    'a1passwd' ],
-            [ 'admin2',    'admin2@example.com',    'a2passwd' ],
+            [qw( username email password first_name last_name)],
+            [
+                'customer1', 'customer1@example.com',
+                'c1passwd',  "Customer",
+                "One"
+            ],
+            [
+                'customer2', 'customer2@example.com',
+                'c1passwd',  "Customer",
+                "Two"
+            ],
+            [
+                'customer3', 'customer3@example.com',
+                'c1passwd',  "Customer",
+                "Three"
+            ],
+            [ 'admin1', 'admin1@example.com', 'a1passwd', "Admin", "One" ],
+            [ 'admin2', 'admin2@example.com', 'a2passwd', "Admin", "Two" ],
         ]
     );
     return $rset;
@@ -1406,6 +1799,10 @@ All attributes have a corresponding C<clear_$attribute> method which deletes all
 
 =item * clear_roles
 
+=item * clear_shipment_carriers
+
+=item * clear_shipment_rates
+
 =item * clear_states
 
 =item * clear_taxes
@@ -1436,6 +1833,10 @@ All attributes have a corresponding C<clear_$attribute> method which deletes all
 
 =item * has_roles
 
+=item * has_shipment_carriers
+
+=item * has_shipment_rates
+
 =item * has_states
 
 =item * has_taxes
